==> Mudlib-CD.00.28.tar.gz: lib/std/player/pcombat.c <==
/*
  /std/player/pcombat.c

  This is a subpart of player_sec.c

  All combat routines that are player specific are handled here.

  This file is included into player_sec.c

  Revision history:

 */

/**************************************************************************

   This is the team routines, players and NPC should not be able to be
   in the same teams.

*/

static object   *team_invited;	/* Array of players invited to team */

/*
 * Prototypes
 */
object *query_invited();

/*
 * Function name:   team_join
 * Description:     Sets this player as the leader of another
 *                  Fails if 'member' not invited.
 * Arguments:	    member: The objectpointer to the new member of my team
 * Returns:         True if member accepted in the team
 */
public int
team_join(object member)
{
    if (member_array(member, team_invited) < 0)	/* Not invited */
	return 0;

    /*
     * Can not be a leader with too low DIS
     */
    if (query_stat(SS_DIS) + 10 < member->query_stat(SS_DIS))
	return 0;

    return ::team_join(member);
}

/*
 * Function name:   team_invite
 * Description:     Invites a new member to my team. This does NOT join the
 *                  member to my team. It only makes it possible for the
 *                  player to join my team.
 * Arguments:	    member: The objectpointer to the invited member.
 *                          If member == 0, the invited list is cleared.
 */
public void
team_invite(object member)
{
    if (!member)
    {
	team_invited = 0;
	return;
    }
    if (member_array(member, query_invited()) >= 0)
	return;
    if (!team_invited)
	team_invited = ({ member });
    else
    team_invited = team_invited + ({ member });
}

/*
 * Function name:   query_invited
 * Description:     Give back an array with objects of players who are
 *                  invited.
 * Returns:         An array of objects
 */
public object *
query_invited()
{
    int             i;
    while ((i = member_array(0, team_invited)) >= 0)
	team_invited = exclude_array(team_invited, i, i);
    return team_invited;
}

/*
 * Function name:   remove_invited
 * Description:     Remove an object from the invited list.
 * Argumnents:      ob - The object to remove from the list.
 */
public void
remove_invited(object ob)
{
    if (team_invited)
	team_invited -= ({ ob });
}

/*
 * Function name:   hit_me
 * Description:     Called to make damage on this object. The actually
 *                  made damage is returned and will be used to change
 *                  the score of the aggressor.
 * Arguments:       wc-penetration, damagetype, Attacker, Attack ID
 * Returns:         The hitresult as given by the external combat object.
 */
public nomask mixed
hit_me(int wcpen, int dt, object attacker, int attack_id)
{
    return ::hit_me(wcpen, dt, attacker, attack_id);
}

==> Mudlib-CD.00.30.tar.gz: lib/std/player/pcombat.c <==
/*
  /std/player/pcombat.c

  This is a subpart of player_sec.c

  All combat routines that are player specific are handled here.

  This file is included into player_sec.c

  Revision history:

 */

/**************************************************************************

   This is the team routines, players and NPC should not be able to be
   in the same teams.

*/

static object   *team_invited;	/* Array of players invited to team */

/*
 * Prototypes
 */
object *query_invited();

/*
 * Function name:   team_join
 * Description:     Sets this player as the leader of another
 *                  Fails if 'member' not invited.
 * Arguments:	    member: The objectpointer to the new member of my team
 * Returns:         True if member accepted in the team
 */
public int
team_join(object member)
{
    if (member_array(member, team_invited) < 0)	/* Not invited */
	return 0;

    /*
     * Can not be a leader with too low DIS unless member is a wizard
     */
    if (query_stat(SS_DIS) + 10 < member->query_stat(SS_DIS) &&
		!member->query_wiz_level())
	return 0;

    return ::team_join(member);
}

/*
 * Function name:   team_invite
 * Description:     Invites a new member to my team. This does NOT join the
 *                  member to my team. It only makes it possible for the
 *                  player to join my team.
 * Arguments:	    member: The objectpointer to the invited member.
 *                          If member == 0, the invited list is cleared.
 */
public void
team_invite(object member)
{
    if (!member)
    {
	team_invited = 0;
	return;
    }
    if (member_array(member, query_invited()) >= 0)
	return;
    if (!team_invited)
	team_invited = ({ member });
    else
    team_invited = team_invited + ({ member });
}

/*
 * Function name:   query_invited
 * Description:     Give back an array with objects of players who are
 *                  invited.
 * Returns:         An array of objects
 */
public object *
query_invited()
{
    int             i;
    while ((i = member_array(0, team_invited)) >= 0)
	team_invited = exclude_array(team_invited, i, i);
    return team_invited;
}

/*
 * Function name:   remove_invited
 * Description:     Remove an object from the invited list.
 * Argumnents:      ob - The object to remove from the list.
 */
public void
remove_invited(object ob)
{
    if (team_invited)
	team_invited -= ({ ob });
}

/*
 * Function name:   hit_me
 * Description:     Called to make damage on this object. The actually
 *                  made damage is returned and will be used to change
 *                  the score of the aggressor.
 * Arguments:       wc-penetration, damagetype, Attacker, Attack ID
 * Returns:         The hitresult as given by the external combat object.
 */
public nomask mixed
hit_me(int wcpen, int dt, object attacker, int attack_id)
{
    return ::hit_me(wcpen, dt, attacker, attack_id);
}
